from distutils.core import setup

setup(
    name='print_item',
    version='1.1.0',
    py_modules=['print_item'],
    author='quoccuong',
    author_email='tqcuong.secure@gmail.com',
    url='',
    description='A simple print item mays contain nested list',
)
